==> hindent-5.2.5-12-armv7h.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.5
id: hindent-5.2.5-E0cTXlP3VO6FKKlcj5VDvr
key: hindent-5.2.5-E0cTXlP3VO6FKKlcj5VDvr
license: BSD3
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
exposed: True
indefinite: False
exposed-modules:
    HIndent HIndent.CabalFile HIndent.Pretty HIndent.Types
abi: 5ecb1fb45cf5f3da50e60ceb4e474a57
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hindent-5.2.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/hindent-5.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.5-E0cTXlP3VO6FKKlcj5VDvr
depends:
    base-4.10.1.0 containers-0.5.10.2 Cabal-2.0.1.0 filepath-1.4.1.2
    directory-1.3.0.2 haskell-src-exts-1.20.1-KzsR5PgidTw6SJhb6STH3W
    monad-loops-0.4.3-4g9tbQ6v5D92QXu31BWMk9
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc bytestring-0.10.8.2
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO transformers-0.5.2.0
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    yaml-0.8.28-AxYrwlMpYX31W5mAcyFp38
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             haskell-src-exts-1.20.1-KzsR5PgidTw6SJhb6STH3W=9bcd7032c7680bc3468fd18e0946001d
             monad-loops-0.4.3-4g9tbQ6v5D92QXu31BWMk9=a9ba7d22f3e2a7048e828e71a170f3e8
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             yaml-0.8.28-AxYrwlMpYX31W5mAcyFp38=2edf0204db486905f3f2a8eea4ac968b
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.2.5-13-armv7h.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.5
id: hindent-5.2.5-2rgOZZxsFIt4NgLiYwMKxq
key: hindent-5.2.5-2rgOZZxsFIt4NgLiYwMKxq
license: BSD3
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
exposed: True
indefinite: False
exposed-modules:
    HIndent HIndent.CabalFile HIndent.Pretty HIndent.Types
abi: 04aa6a987482cc1f7a4173ff9677ac32
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hindent-5.2.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/hindent-5.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.5-2rgOZZxsFIt4NgLiYwMKxq
depends:
    base-4.10.1.0 containers-0.5.10.2 Cabal-2.0.1.0 filepath-1.4.1.2
    directory-1.3.0.2 haskell-src-exts-1.20.1-KzsR5PgidTw6SJhb6STH3W
    monad-loops-0.4.3-4g9tbQ6v5D92QXu31BWMk9
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc bytestring-0.10.8.2
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO transformers-0.5.2.0
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    yaml-0.8.28-GiNMUmTIxNr1TbhM7TBaCz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             haskell-src-exts-1.20.1-KzsR5PgidTw6SJhb6STH3W=9bcd7032c7680bc3468fd18e0946001d
             monad-loops-0.4.3-4g9tbQ6v5D92QXu31BWMk9=a9ba7d22f3e2a7048e828e71a170f3e8
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             yaml-0.8.28-GiNMUmTIxNr1TbhM7TBaCz=c14a845bf2cc562a50d933b052271799
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
